-- stuff we use
local setmetatable, tonumber, tostring = setmetatable, tonumber, tostring

local io                     = require("io")
local oo                     = require("loop.simple")
local string                 = require("string")
local os                     = require("os")

local Applet                 = require("jive.Applet")
local Framework              = require("jive.ui.Framework")
local Icon                   = require("jive.ui.Icon")
local Textarea               = require("jive.ui.Textarea")
local Popup                  = require("jive.ui.Popup")
local Group                  = require("jive.ui.Group")
local SimpleMenu             = require("jive.ui.SimpleMenu")
local Window                 = require("jive.ui.Window")
local Sample                 = require("squeezeplay.sample")
local JIVE_VERSION   = jive.JIVE_VERSION

local log                    = require("jive.utils.log").addCategory("headphone", jive.utils.log.DEBUG)


module(..., Framework.constants)
oo.class(_M, Applet)


function menu(self, menuItem)

	log:info("menu")

	-- Menu	
	local menu = SimpleMenu("menu",
		{
			{
				text = self:string("TEXT_HEADSET_ON"),
				callback = 
					function()
						log:info(self:string("headphone on selected"))
						self:headphoneOn()
					end
			},
			{
				text = self:string("TEXT_SPEAKER_ON"), 
				callback = 
					function()
						log:info(self:string("speaker on selected"))
						self:speakerOn()
					end
			},
		
		})

	local window = Window("window", self:string("TEXT_MENU_TEXT")) 
	window:addWidget(menu)

	self:tieAndShowWindow(window)
	return window
end


function headphoneOn(self)
	self:infoMessage(self:string("TEXT_HEADSET_IS_ON"), 3000)
	
	os.execute("amixer -q sset Headphone 92%")
	os.execute("amixer -q sset Endpoint Headphone")
	Sample:setEffectAttenuation(Sample.MAXVOLUME / 4)

end

function speakerOn(self)
	self:infoMessage(self:string("TEXT_LAUDSPEAKER_IS_ON"), 3000)

	os.execute("amixer -q sset Endpoint Speaker")
	Sample:setEffectAttenuation(Sample.MAXVOLUME)

end

function infoMessage(self, info, time)
	-- 7.4 styles
	local popupStyle="toast_popup_text"
	local textStyle="toast_popup_textarea"

	if string.sub(JIVE_VERSION,0,3)=="7.3" then
		-- 7.3 styles
		popupStyle="currentsong"
		textStyle="popupplay"
	end
     
       -- create a Popup with message in 7.4 or 7.3 style
       local infoPopup = Popup(popupStyle)
       local infoMessage = Textarea(textStyle, self:string(info))
	local infoGroup = Group("group", {
			text = infoMessage,
	      })
       infoPopup:addWidget(infoGroup)
 
       -- display the message for 3 seconds
       infoPopup:showBriefly(time, nil, Window.transitionPushPopupUp, Window.transitionPushPopupDown)
end